import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import gaDataset from '../../utils/gaDataset';
import UserDefaultAvatar from '../../assets/user-avatar.svg';
import styles from './AnueAccount.scss';

const cx = classNames.bind(styles);

const AnueAccount = ({ isLogin, avatarSrc, userName, onLogin, onRegister, onClick, dataPrefix }) => {
  // 登入前顯示
  const loginOptions = (
    <React.Fragment>
      <span
        className={cx('button', 'user-login')}
        onClick={onLogin && onLogin}
        {...gaDataset({ dataPrefix, category: 'Header', action: 'click', label: 'avatar' })}
      >
        登入
      </span>
      <span
        className={cx('button', 'user-register')}
        onClick={onRegister && onRegister}
        {...gaDataset({ dataPrefix, category: 'Header', action: 'click', label: 'signup' })}
      >
        註冊
      </span>
    </React.Fragment>
  );

  // 登入後顯示
  const loginedInfo = (
    <span className={cx('button', 'user-info')} onClick={onClick} title={userName}>
      {userName}
    </span>
  );

  const avatar = !avatarSrc ? UserDefaultAvatar : avatarSrc;

  return (
    <div className={cx('user-login-wrapper')}>
      <img src={avatar} className={cx('user-avatar')} alt="Avatar" />
      {isLogin ? loginedInfo : loginOptions}
    </div>
  );
};

AnueAccount.propTypes = {
  isLogin: PropTypes.bool,
  avatarSrc: PropTypes.string,
  userName: PropTypes.string,
  onLogin: PropTypes.func,
  onRegister: PropTypes.func,
  onClick: PropTypes.func,
  dataPrefix: PropTypes.arrayOf(PropTypes.string),
};

AnueAccount.defaultProps = {
  isLogin: false,
  avatarSrc: null,
  userName: '',
  onLogin: () => {},
  onRegister: () => {},
  onClick: () => {},
  dataPrefix: ['data-global-ga'],
};

export default React.memo(AnueAccount);
