/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import * as knobs from '@storybook/addon-knobs/react';
import defaultNotes from './AnueAccount.md';
import AnueNavigator from '../../AnueNavigator/AnueNavigator';
import AnueAccount from '../AnueAccount';
import styles from './stories.style.scss';

// eslint-disable-next-line react/prop-types
const DesktopHeaderWrapper = ({ menu }) => {
  return (
    <div className={styles.wrapper}>
      <AnueNavigator channel="台股" accountComponent={menu} />
      <div className={styles.content}>long content here...</div>
    </div>
  );
};

const stories = storiesOf('AnueAccount', module);

stories.addDecorator(knobs.withKnobs);

stories.add(
  'Desktop: un-login',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return <DesktopHeaderWrapper menu={<AnueAccount />} />;
    })
  )
);

stories.add(
  'Desktop: logined',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return <DesktopHeaderWrapper menu={<AnueAccount isLogin userName="Anthony" />} />;
    })
  )
);

stories.add(
  'Desktop: logined with long name',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return <DesktopHeaderWrapper menu={<AnueAccount isLogin userName="Anthony Tony Stack" />} />;
    })
  )
);

stories.add(
  'Desktop: logined with avatar',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <DesktopHeaderWrapper
          menu={
            <AnueAccount
              isLogin
              userName="鋼鐵人"
              avatarSrc="https://afkarena-character-ranking.xyz/img/chara/stand/3.png"
            />
          }
        />
      );
    })
  )
);

// stories.add(
//   'Desktop: un-login highlight',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return <DesktopHeaderWrapper menu={<AnueAccount highlight />} />;
//     })
//   )
// );

// stories.add(
//   'Desktop: login with avatar',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return (
//         <DesktopHeaderWrapper
//           menu={
//             <AnueAccount
//               name="Anthony Edward Tony Stark"
//               avatar="https://www.impericon.com/360x520x85/media/catalog/product/a/b/abyacc243_lg.jpg"
//               isLogin
//             />
//           }
//         />
//       );
//     })
//   )
// );

// stories.add(
//   'Desktop: custom popup',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return (
//         <DesktopHeaderWrapper
//           menu={
//             <AnueAccount
//               name="Anthony Edward Tony Stark"
//               avatar="https://www.impericon.com/360x520x85/media/catalog/product/a/b/abyacc243_lg.jpg"
//               isLogin
//               popup={{
//                 row: [
//                   [
//                     { name: '選單A', link: 'https://www.cnyes.com' },
//                     { name: '選單B', link: 'https://www.cnyes.com' },
//                     { name: '選單C', link: 'https://www.cnyes.com' },
//                   ],
//                   [
//                     { name: '選單A', link: 'https://www.cnyes.com' },
//                     { name: '選單B', link: 'https://www.cnyes.com' },
//                     { name: '選單C', link: 'https://www.cnyes.com' },
//                   ],
//                   [{ name: '會員中心', link: 'https://www.cnyes.com' }, { name: '登出', onClick: () => alert('登出') }],
//                 ],
//               }}
//             />
//           }
//         />
//       );
//     })
//   )
// );

// stories.add(
//   'Desktop: login wo avatar',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return <DesktopHeaderWrapper menu={<AnueAccount name="Anthony Edward Tony Stark" isLogin />} />;
//     })
//   )
// );

// stories.add(
//   'Mobile: un-login',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return <MobileHeaderWrapper menu={<AnueAccount hideName />} />;
//     })
//   )
// );

// stories.add(
//   'Mobile: un-login highlight',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return <MobileHeaderWrapper menu={<AnueAccount hideName highlight />} />;
//     })
//   )
// );

// stories.add(
//   'Mobile: login with avatar',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return (
//         <MobileHeaderWrapper
//           menu={
//             <AnueAccount
//               align="right"
//               avatar="https://www.impericon.com/360x520x85/media/catalog/product/a/b/abyacc243_lg.jpg"
//               name="passenger00002"
//               hideName
//               isLogin
//               popup={{
//                 row: [[{ name: '登出', onClick: () => alert('登出') }]],
//               }}
//             />
//           }
//         />
//       );
//     })
//   )
// );

// stories.add(
//   'Mobile: login with invalid avatar',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return (
//         <MobileHeaderWrapper
//           menu={
//             <AnueAccount
//               align="right"
//               avatar="https://lh4.googleusercontent.com/-fPjNYnV7MzU/AAAAAAAAAAI/AAAAAAAAAAA/AAnnY7r1dkaAcrXYXREKmuRg0yY-GaMteA/mo/photo.jpg?sz=50"
//               name="passenger00002"
//               hideName
//               isLogin
//               popup={{
//                 row: [[{ name: '登出', onClick: () => alert('登出') }]],
//               }}
//             />
//           }
//         />
//       );
//     })
//   )
// );

// stories.add(
//   'Mobile: login wo avatar',
//   withNotes(defaultNotes)(
//     withInfo()(() => {
//       return <MobileHeaderWrapper menu={<AnueAccount hideName isLogin />} />;
//     })
//   )
// );
