import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import * as knobs from '@storybook/addon-knobs/react';
import AnueNavigator from '../AnueNavigator';
import AnueAccount from '../../AnueAccount/AnueAccount';
import SwitchVersionButton from '../../SwitchVersionButton/SwitchVersionButton';
import defaultNotes from './AnueNavigator.md';
import styles from './stories.style.scss';

const stories = storiesOf('AnueNavigator', module);

stories.addDecorator(knobs.withKnobs);
stories.addDecorator(story => (
  <div className={styles.wrapper}>
    {story()}
    <div className={styles.container}>
      <div className={styles.content}>
        Mac 環境下，可透過 `Shift + Command + F` 切換成全螢幕模式檢視，會比較貼近真實情況
      </div>
    </div>
  </div>
));

stories.add(
  '預設',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return <AnueNavigator apiEnv="beta" switchVersionComponent={<SwitchVersionButton />} />;
    })
  )
);

stories.add(
  '設定搜尋關鍵字',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return <AnueNavigator apiEnv="beta" searchKeyword="台積電" />;
    })
  )
);

stories.add(
  '無切換新舊版本按鈕',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return <AnueNavigator apiEnv="beta" />;
    })
  )
);

stories.add(
  '加上登入選項',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <AnueNavigator
          apiEnv="beta"
          accountComponent={
            <AnueAccount
              onLogin={() => {
                console.log('點擊登入!');
              }}
              onRegister={() => {
                console.log('點擊註冊!');
              }}
            />
          }
        />
      );
    })
  )
);

stories.add(
  '加上登入選項並移除切換新舊版本按鈕',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <AnueNavigator
          apiEnv="beta"
          enableSwitchVersion={false}
          accountComponent={
            <AnueAccount
              needDivider={false}
              onLogin={() => {
                console.log('點擊登入!');
              }}
              onRegister={() => {
                console.log('點擊註冊!');
              }}
            />
          }
        />
      );
    })
  )
);
