/* eslint-disable react/no-array-index-key */
/* eslint-disable no-unused-expressions */
import React, { Component } from 'react';
import { DFPProvider, AdSlot } from 'cnyes-dfp';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import AdProfiles from '../DFPProviderWrapper/AdProfiles';
import LoadingSkeleton from '../../components/LoadingSkeleton/LoadingSkeleton';
import styles from './BrandWallSlide.scss';

const BRANDS_WALL_AD_UNIT_SUFFIXES = [['A', 'B', 'C', 'D'], ['E', 'F', 'G', 'H'], ['I', 'J', 'K', 'L']];
const DEFAULT_WAIT_LOADING_MILLION_SECOND = 3500;
const cx = classnames.bind(styles);

function convertAdProfileFormat(adProfileSource, adRowAmount) {
  if (!adProfileSource || !adProfileSource.length) return BRANDS_WALL_AD_UNIT_SUFFIXES;

  const result = [];
  const adProfileSourceArray = adProfileSource.reduce((acc, key) => {
    acc.push(key);

    return acc;
  }, []);

  while (adProfileSourceArray.length) {
    result.push(adProfileSourceArray.splice(0, adRowAmount));
  }

  return result;
}

class BrandWallSlider extends Component {
  static propTypes = {
    position: PropTypes.oneOf(['Top']),
    delay: PropTypes.number,
    adWidth: PropTypes.number,
    adWidthUnit: PropTypes.string,
    adProfileSource: PropTypes.shape({}),
    adRowAmount: PropTypes.number,
  };

  static defaultProps = {
    position: 'Top',
    delay: 10000,
    adWidth: 334,
    adWidthUnit: 'px',
    adProfileSource: {},
    adRowAmount: 4,
  };

  constructor(props) {
    super(props);

    const { adProfileSource, adRowAmount } = props;
    const adProfileSources = Object.keys(adProfileSource);
    const haveAdProfileSource = adProfileSources.length > 0;
    const adProfiles = convertAdProfileFormat(adProfileSources, adRowAmount);
    const adBrandWallCount = haveAdProfileSource
      ? Math.ceil(adProfileSources.length / adRowAmount)
      : BRANDS_WALL_AD_UNIT_SUFFIXES.length;

    this.state = {
      currentIndex: 0,
      loading: true,
      // adProfiles: [...adProfiles, adProfiles[0]],
      adProfiles,
      adBrandWallCount,
      animationStep: 1,
      cloneFirstSlide: null,
    };

    this.haveAdProfileSource = haveAdProfileSource;
    this.totalCount = adBrandWallCount + 1;
    this.displayCount = adBrandWallCount;
  }

  // componentDidMount() {
  //   this.startAutoPlay();
  // }

  componentDidUpdate(nextProps, nextState) {
    if (this.state.loading !== nextState.loading) {
      this.startAutoPlay();
    }
  }

  componentWillUnmount() {
    this.stopAutoPlay();
  }

  startAutoPlay = () => {
    this.stopAutoPlay();

    this.timerID = setInterval(() => {
      this.handleClickToNext();
    }, this.props.delay);
  };

  stopAutoPlay = () => {
    clearInterval(this.timerID);
  };

  handleClickToNext = () => {
    const { currentIndex } = this.state;
    const direction = 1;

    if (currentIndex % this.totalCount !== this.displayCount && currentIndex >= 0) {
      this.setState(prevState => {
        const newIndex = prevState.currentIndex + direction;

        return {
          animationStep: 1,
          currentIndex: newIndex % this.totalCount,
        };
      });
    }
  };

  handleSlotAdReady = () => {
    this.state.loading &&
      setTimeout(() => {
        this.setState({ loading: false });
      }, DEFAULT_WAIT_LOADING_MILLION_SECOND);
  };

  handlerTransitionEnd = () => {
    const { currentIndex } = this.state;

    if (currentIndex % this.totalCount === this.displayCount) {
      this.setState({
        animationStep: 0,
        currentIndex: 0,
      });
    }
  };

  handleDotClick = index => {
    this.setState({
      animationStep: 0.3,
      currentIndex: index,
    });
  };

  renderBrandBlock = (block, i) => {
    const { position, adWidth, adWidthUnit, adRowAmount } = this.props;
    const emptyRowCount = adRowAmount - block.length;

    return (
      <div key={`brand-block-${position}-${i}`} style={{ width: `${adWidth}${adWidthUnit}` }}>
        {block.map(this.renderRow)}
        {emptyRowCount > 0 &&
          Array(emptyRowCount)
            .fill(0)
            .map(this.renderEmptyRow)}
      </div>
    );
  };

  renderRow = code => {
    const { loading } = this.state;
    const { position, adProfileSource } = this.props;
    const adSource = this.haveAdProfileSource ? adProfileSource[code] : AdProfiles[`brandsWall${position}${code}`];

    return (
      <div className={cx('row')} key={`${position}-${code}`}>
        {loading && <LoadingSkeleton />}
        {<AdSlot profile={adSource} lazyLoading={false} asyncInit={200} />}
      </div>
    );
  };

  renderEmptyRow = (_, index) => {
    const { position } = this.props;

    return (
      <div
        key={`empty-${position}-${index}`}
        style={{ backgroundColor: 'transparent', height: '60px', borderBottom: '1px solid #f1f1f1' }}
      />
    );
  };

  renderBrandEmptyBlock = () => {
    const { position, adWidth, adWidthUnit, adRowAmount } = this.props;

    return (
      <div key={`brand-block-${position}-999}`} style={{ width: `${adWidth}${adWidthUnit}` }}>
        {Array(adRowAmount)
          .fill(0)
          .map(this.renderEmptyRow)}
      </div>
    );
  };

  renderDots() {
    const dots = Array(this.displayCount).fill(0);
    const { currentIndex } = this.state;

    return (
      <div className={cx('dots')}>
        <ul className={cx('dot-wrapper')}>
          {dots.map((_, index) => {
            const isActive = currentIndex === index || currentIndex === index + this.displayCount;

            return (
              <div
                key={`dot-${index}`}
                className={cx('dot', { active: isActive })}
                onClick={() => this.handleDotClick(index)}
              />
            );
          })}
        </ul>
      </div>
    );
  }

  /**
   * 輪播參考:
   * https://www.cnblogs.com/slongs/p/10189439.html
   */
  render() {
    const { animationStep } = this.state;
    const { adWidth, adWidthUnit } = this.props;
    const { currentIndex, adProfiles } = this.state;

    const transAnimationStep = currentIndex === this.displayCount ? 1 : animationStep;
    const transformWidth = `${this.totalCount * adWidth}${adWidthUnit}`;
    const transformX = `translateX(-${currentIndex * adWidth}${adWidthUnit})`;

    return (
      <DFPProvider onSlotRenderEnded={this.handleSlotAdReady}>
        <div className={cx('container')}>
          <div className={cx('brandWall')}>
            <div
              ref={this.slideRef}
              id="brandWallSlide"
              className={cx('brandWall__body')}
              onTransitionEnd={this.handlerTransitionEnd}
              style={{
                transition: `transform ${transAnimationStep}s`,
                width: `${transformWidth}`,
                transform: transformX,
              }}
            >
              {adProfiles.map(this.renderBrandBlock)}
              {this.renderBrandEmptyBlock()}
            </div>
          </div>
          {this.renderDots()}
        </div>
      </DFPProvider>
    );
  }
}

export default BrandWallSlider;
