/* eslint-disable no-unused-expressions */
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import useCookies from '../../hooks/cookie';
import gaDataset from '../../utils/gaDataset';
import SwitchIcon from '../../assets/icon-trad.svg';
import styles from './SwitchVersionButton.scss';

export const NEW_VERSION = 'new';
export const OLD_VERSION = 'old';
export const CURRENT_USE_VERSION = 'anue.current.useVersion';

const cx = classNames.bind(styles);

const SwitchVersionButton = React.memo(
  ({ defaultVersion, dataPrefix, onSwitchVersion, divider, className, iconClassName, textClassName }) => {
    const [isLoading, setIsLoading] = useState(false);
    const [useVersionCookie, setUseVersionCookie] = useCookies(CURRENT_USE_VERSION, defaultVersion);

    const switchVersionHandler = () => {
      const changedVersion = useVersionCookie === NEW_VERSION ? OLD_VERSION : NEW_VERSION;

      setUseVersionCookie(changedVersion, { secure: true });
      setIsLoading(true);
      onSwitchVersion && onSwitchVersion(changedVersion);
    };

    const switchVersion =
      useVersionCookie === NEW_VERSION
        ? { label: '舊版', event: 'version_old' }
        : { label: '新版', event: 'version_new' };

    const dividerSettings = {
      'divider-right': divider === 'right',
      'divider-left': divider === 'left',
    };

    const style = className.length > 0 ? className : cx('switch-wrapper', dividerSettings);
    const iconStyle = iconClassName.length > 0 ? iconClassName : cx('icon');
    const buttonStyle = textClassName.length > 0 ? textClassName : cx('switch-button');

    // 用 CSS 撰寫出來的讀取進度
    // https://loading.io/css/
    const ringLoading = (
      <div className={cx('lds-ring')}>
        <div />
        <div />
        <div />
        <div />
      </div>
    );

    return (
      <div className={style}>
        <img src={SwitchIcon} className={iconStyle} alt="Switch" />
        <div
          className={buttonStyle}
          {...gaDataset({ dataPrefix, category: 'Header', action: 'VerSwitch', label: switchVersion.event })}
          onClick={switchVersionHandler}
        >
          {isLoading ? ringLoading : switchVersion.label}
        </div>
      </div>
    );
  }
);

SwitchVersionButton.propTypes = {
  className: PropTypes.string,
  iconClassName: PropTypes.string,
  textClassName: PropTypes.string,
  defaultVersion: PropTypes.string,
  dataPrefix: PropTypes.arrayOf(PropTypes.string),
  onSwitchVersion: PropTypes.func,
  divider: PropTypes.oneOf(['left', 'none', 'right']),
};

SwitchVersionButton.defaultProps = {
  className: '',
  iconClassName: '',
  textClassName: '',
  defaultVersion: OLD_VERSION,
  dataPrefix: ['data-global-ga'],
  onSwitchVersion: () => {},
  divider: 'left',
};

export default SwitchVersionButton;
